<?php

namespace Drupal\report_station\Entity\Controller;

use Drupal\Component\Render\FormattableMarkup;
use Drupal\Core\Entity\EntityInterface;
use Drupal\Core\Entity\EntityListBuilder;

/**
 * The entity list builder handler for report station entities.
 */
class ReportStationListBuilder extends EntityListBuilder {

  /**
   * {@inheritdoc}
   */
  public function buildHeader(): array {
    return [
      'label' => $this->t('Report station'),
      'active' => $this->t('Active'),
      'environment' => $this->t('Environment'),
    ] + parent::buildHeader();
  }

  /**
   * {@inheritdoc}
   */
  public function buildRow(EntityInterface $entity): array {
    /** @var \Drupal\report_station\Entity\ReportStationInterface $entity */
    return [
      'label' => new FormattableMarkup('@label (@name)', [
        '@label' => $entity->label(),
        '@name' => $entity->getName(),
      ]),
      'active' => $entity->isPublished() ? $this->t('Yes') : $this->t('No'),
      'environment' => $entity->environment->value ?? 'default',

    ] + parent::buildRow($entity);
  }

  /**
   * {@inheritdoc}
   */
  public function getDefaultOperations(EntityInterface $entity): array {
    $operations = parent::getDefaultOperations($entity);

    if ($entity->access('view')) {
      $operations['view'] = [
        'title' => $this->t('View'),
        'weight' => -5,
        'url' => $entity->toUrl('canonical'),
      ];
    }

    return $operations;
  }

}
