<?php

namespace Drupal\report_station\Entity\Display;

use Drupal\Core\Entity\EntityTypeInterface;
use Drupal\Core\Entity\EntityViewBuilder;
use Drupal\report_station\Plugin\ReportListBuilderManagerInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Entity view builder for report station entities.
 *
 * Adds the handling of building the report list display for report station
 * displays.
 */
class ReportStationViewBuilder extends EntityViewBuilder {

  /**
   * The report list builder plugin manager.
   *
   * @var \Drupal\report_station\Plugin\ReportListBuilderManagerInterface|null
   */
  protected ?ReportListBuilderManagerInterface $listBuilderManager;

  /**
   * {@inheritdoc}
   */
  public static function createInstance(ContainerInterface $container, EntityTypeInterface $entity_type) {
    $instance = parent::createInstance($container, $entity_type);
    $listBuilderManager = $container->get('plugin.manager.report_station.list_builder');
    $instance->setListBuilderManager($listBuilderManager);
    return $instance;
  }

  /**
   * Sets the report list builder manager.
   *
   * @param \Drupal\report_station\Plugin\ReportListBuilderManagerInterface $list_builder_manager
   *   The report list builder plugin manager.
   *
   * @return self
   *   The instance for method chainging.
   */
  public function setListBuilderManager(ReportListBuilderManagerInterface $list_builder_manager): self {
    $this->listBuilderManager = $list_builder_manager;
    return $this;
  }

  /**
   * {@inheritdoc}
   */
  public function buildComponents(array &$build, array $entities, array $displays, $view_mode) {
    parent::buildComponents($build, $entities, $displays, $view_mode);

    if ($component = $displays['report_station']->getComponent('reports')) {
      $builderId = $component['settings']['type'] ?? $this->listBuilderManager->getFallbackPluginId('', $component['settings']);
      $reportBuilder = $this->listBuilderManager->createInstance($builderId, $component['settings']);

      foreach ($entities as $id => $entity) {
        $build[$id]['reports'] = $reportBuilder->buildList($entity);
      }
    }
  }

}
