<?php

namespace Drupal\report_station\Entity;

use Drupal\Core\Entity\ContentEntityInterface;

/**
 * A single report entry.
 *
 * Reports are created when a server beacon transmits a report and are never
 * edited or updated through forms. Reports are uniquely identified by UUIDs
 * that should prevent replay of transmission (should not see same UUID again).
 */
interface ReportEntryInterface extends ContentEntityInterface {

  /**
   * Get the timestamp for when this report entry was created.
   *
   * @return int
   *   The timestamp value for when this report entry was created.
   */
  public function getCreated(): int;

  /**
   * Gets the report station that this report belongs to.
   *
   * @return \Drupal\report_station\Entity\ReportStationInterface|null
   *   The report station that this report entry belongs to.
   */
  public function getStation(): ?ReportStationInterface;

  /**
   * Get the environment identifier for this report.
   *
   * @return string|null
   *   The name of the environment if one is available.
   */
  public function getEnvironment(): ?string;

  /**
   * Get the report summary as a renderable array.
   *
   * @return array
   *   Renderable summary for the server report data.
   */
  public function getSummary(): array;

  /**
   * Get the renderable array to build the report display.
   *
   * @return array
   *   The report renderable to display the report data.
   */
  public function toRenderable(): array;

  /**
   * Regenerate the report summary.
   *
   * Used to generate the report summary from the server beacon handler plugins.
   * The summaries can than be stored and quick over view displays.
   */
  public function updateSummary(): void;

}
