<?php

namespace Drupal\report_station\Entity;

use Drupal\Core\Entity\ContentEntityInterface;
use Drupal\Core\Entity\EntityPublishedInterface;
use Drupal\Core\Entity\FieldableEntityInterface;
use Drupal\report_station\Plugin\ReportReceiverInterface;
use Drupal\user\EntityOwnerInterface;

/**
 * The base interface for a ReportStation entity.
 */
interface ReportStationInterface extends ContentEntityInterface, EntityPublishedInterface, EntityOwnerInterface, FieldableEntityInterface {

  /**
   * Get the unique report station string identifier.
   *
   * Name is used for routes and machine name, and is unique.
   *
   * @return string
   *   Get the report station name identifier.
   */
  public function getName(): string;

  /**
   * Get the transmission receiver for this report station.
   *
   * Plugin for receiving the report transmitted by a beacon, receiver must
   * be configured to match the protocol and keys of the sending transmitter.
   *
   * @return \Drupal\report_station\Plugin\ReportReceiverInterface|null
   *   The receiver plugin configured for this report station if available. NULL
   *   is returned if the plugin was unable to load, possibily due to the
   *   provider module being unavailable.
   */
  public function getReceiver(): ?ReportReceiverInterface;

}
