<?php

namespace Drupal\report_station\ParamConverter;

use Drupal\Core\Entity\EntityFieldManagerInterface;
use Drupal\Core\Entity\EntityStorageInterface;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\ParamConverter\ParamConverterInterface;
use Symfony\Component\Routing\Route;

/**
 * The route parameter converter for report_station entities by name.
 */
class ReportStationName implements ParamConverterInterface {

  /**
   * The report station entity storage handler.
   *
   * @var \Drupal\Core\Entity\EntityStorageInterface
   */
  protected EntityStorageInterface $stationStorage;

  /**
   * Creates a new instance of the ReportStationName parameter converter.
   *
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entityTypeManager
   *   The entity type manager.
   * @param \Drupal\Core\Entity\EntityFieldManagerInterface $fieldManager
   *   The entity field manager.
   */
  public function __construct(EntityTypeManagerInterface $entityTypeManager, protected EntityFieldManagerInterface $fieldManager) {
    $this->stationStorage = $entityTypeManager->getStorage('report_station');
  }

  /**
   * {@inheritdoc}
   */
  public function convert($value, $definition, $name, array $defaults): mixed {
    [, $field] = explode(':', $definition['type'], 2);

    $ids = $this->stationStorage
      ->getQuery()
      ->accessCheck(FALSE)
      ->condition('status', 1)
      ->condition($field, $value)
      ->range(0, 1)
      ->execute();

    return $ids ? $this->stationStorage->load(reset($ids)) : NULL;
  }

  /**
   * {@inheritdoc}
   */
  public function applies($definition, $name, Route $route): bool {
    if (!empty($definition['type'])) {
      $getFields = $this->fieldManager->getBaseFieldDefinitions(...);
      @[$type, $field] = explode(':', $definition['type'], 2);

      return 'report_station' === $type && isset($getFields('report_station')[$field]);
    }
    return FALSE;
  }

}
