<?php

namespace Drupal\report_station\Plugin;

use Drupal\Core\Cache\CacheBackendInterface;
use Drupal\Core\Extension\ModuleHandlerInterface;
use Drupal\Core\Plugin\DefaultPluginManager;
use Drupal\report_station\Attribute\ReportStationListBuilder;

/**
 * The default implmentation of the report list builder plugin manager.
 */
class ReportListBuilderManager extends DefaultPluginManager implements ReportListBuilderManagerInterface {

  /**
   * Create a new instance of the ReportListBuilderManager plugin manager class.
   *
   * @param \Traversable $namespaces
   *   The namespaces to search for plugin instances with.
   * @param \Drupal\Core\Cache\CacheBackendInterface $cacheBackend
   *   The discovery cache backend for storing plugin definitions.
   * @param \Drupal\Core\Extension\ModuleHandlerInterface $moduleHandler
   *   The module handler.
   */
  public function __construct(\Traversable $namespaces, CacheBackendInterface $cacheBackend, ModuleHandlerInterface $moduleHandler) {
    parent::__construct(
      'Plugin/ReportStation/ListBuilder',
      $namespaces,
      $moduleHandler,
      ReportListBuilderInterface::class,
      ReportStationListBuilder::class
    );

    $this->alterInfo('report_station_list_builder');
    $this->setCacheBackend($cacheBackend, 'report_station.list_builder');
  }

  /**
   * {@inheritdoc}
   */
  public function getFallbackPluginId($plugin_id, array $configuration = []): string {
    return 'report_builder';
  }

}
