<?php

namespace Drupal\report_station\Plugin;

use Drupal\Component\Plugin\ConfigurableInterface;
use Drupal\Component\Plugin\PluginInspectionInterface;
use Drupal\Core\Plugin\PluginFormInterface;
use Drupal\report_station\Entity\ReportStationInterface;
use Symfony\Component\HttpFoundation\Request;

/**
 * Receiver plugins match the protocol of server beacon transmitter plugins.
 *
 * Receivers need to match the transmitter plugins of the server sending the
 * report data. The protocol determines how the report is encoded and secured.
 */
interface ReportReceiverInterface extends PluginInspectionInterface, ConfigurableInterface, PluginFormInterface {

  /**
   * Get the name of the report station owning this receiver.
   *
   * @return string
   *   The name of the report station owning this receiver.
   */
  public function getStationName(): string;

  /**
   * Sets the report station that owns this receiver.
   *
   * @param \Drupal\report_station\Entity\ReportStationInterface $reportStation
   *   The report station which owns this receiver instance.
   *
   * @return self
   *   The receiver itself for chaining.
   */
  public function setReportStation(ReportStationInterface $reportStation): self;

  /**
   * Receive the transmission request and extract the report data.
   *
   * @param \Symfony\Component\HttpFoundation\Request $request
   *   The HTTP request which is transmitting a server beacon report.
   *
   * @return array
   *   The beacon report contents. Server Beacon handler plugins should be used
   *   to validate and display the report contents.
   *
   * @throws \Drupal\report_station\Exception\TransmissionException
   */
  public function __invoke(Request $request): array;

}
