<?php

namespace Drupal\report_station\Plugin;

use Drupal\Component\Plugin\Exception\PluginNotFoundException;
use Drupal\Core\Cache\CacheBackendInterface;
use Drupal\Core\Extension\ModuleHandlerInterface;
use Drupal\Core\Plugin\DefaultPluginManager;
use Drupal\Core\StringTranslation\TranslatableMarkup;
use Drupal\report_station\Attribute\ReportStationReceiver;
use Drupal\report_station\Plugin\ReportStation\Receiver\None;

/**
 * Default plugin manager for the report station receivers.
 */
class ReportReceiverPluginManager extends DefaultPluginManager implements ReportReceiverPluginManagerInterface {

  /**
   * Creates a new instance of the ReportReceiverPluginManager service.
   *
   * @param \Traversable $namespaces
   *   The module namespaces to discovery plugins.
   * @param \Drupal\Core\Cache\CacheBackendInterface $cacheBackend
   *   The cache backend to store plugin definitions.
   * @param \Drupal\Core\Extension\ModuleHandlerInterface $moduleHandler
   *   The module handler service.
   */
  public function __construct(\Traversable $namespaces, CacheBackendInterface $cacheBackend, ModuleHandlerInterface $moduleHandler) {
    parent::__construct(
      'Plugin/ReportStation/Receiver',
      $namespaces,
      $moduleHandler,
      ReportReceiverInterface::class,
      ReportStationReceiver::class
    );

    $this->alterInfo('report_station_receiver');
    $this->setCacheBackend($cacheBackend, 'report_station_receiver');
  }

  /**
   * {@inheritdoc}
   */
  public function getReceiverOptions(): array {
    // Get the list of receiver plugin options.
    return array_column($this->getDefinitions(), 'label', 'id');
  }

  /**
   * {@inheritdoc}
   */
  public function getFallbackInstance(): ReportReceiverInterface {
    return new None([], 'none', [
      'id' => 'none',
      'label' => new TranslatableMarkup('Null receiver'),
      'description' => new TranslatableMarkup('Fallback resolver for missing plugins. Should not be used directly.'),
    ]);
  }

  /**
   * {@inheritdoc}
   */
  public function createInstance($plugin_id, array $configuration = []): ReportReceiverInterface {
    try {
      return $this->getFactory()->createInstance($plugin_id, $configuration);
    }
    catch (PluginNotFoundException) {
      return $this->getFallbackInstance();
    }
  }

}
