<?php

namespace Drupal\report_station\Plugin;

use Drupal\Component\Plugin\PluginManagerInterface;

/**
 * The interface for defining the report receiver plugin manager.
 */
interface ReportReceiverPluginManagerInterface extends PluginManagerInterface {

  /**
   * Get a list of available receiver plugins.
   *
   * Get a list of receiver plugin options which are compatible with Form API
   * "#option" property of "select" and "checkboxes" form elements.
   *
   * @return array<\Stringable|string>
   *   List of available receiver plugins with the plugin IDs as the array
   *   key, and the plugin label as they array value.
   */
  public function getReceiverOptions(): array;

  /**
   * Gets a "null" receiver plugin instance to use as a fallback.
   *
   * Can be used for new report station entities or as a fallback when a plugin
   * is missing because a extension has been removed. Prevent the crashing in
   * ways that don't allow admins to fix the issue.
   *
   * @return \Drupal\report_station\Plugin\ReportReceiverInterface
   *   A fallback null implementation of the receiver plugin type.
   */
  public function getFallbackInstance(): ReportReceiverInterface;

}
