<?php

namespace Drupal\report_station\Strategy;

use Drupal\toolshed\Strategy\StrategyDefinitionBase;

/**
 * A strategy definition for a report renderable implementation.
 *
 * The definition applies to the Report data rendering strategy types. Currently
 * this includes the report renderers and summarizers.
 */
class ReportRenderDefinition extends StrategyDefinitionBase {

  /**
   * Get the types of server beacon plugins this renderer works with.
   *
   * @var string[]
   */
  protected readonly array $beaconTypes;

  /**
   * Creates a new instance of the ReportRenderDefintion class.
   *
   * @param string $id
   *   The render strategy ID.
   * @param array $definition
   *   The render strategy definition.
   */
  public function __construct(string $id, array $definition) {
    parent::__construct($id, $definition);

    $this->beaconTypes = $definition['beacon_types'] ?? [];
  }

  /**
   * Get the list of server beacon plugin types this renderer works with.
   *
   * @return string[]
   *   List of server beacon types that this renderer is compatible with.
   */
  public function getBeaconTypes(): array {
    return $this->beaconTypes;
  }

}
