<?php

namespace Drupal\report_station\Strategy;

use Drupal\Core\Cache\CacheBackendInterface;
use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Extension\ModuleHandlerInterface;
use Drupal\report_station\Attribute\ReportRenderer;
use Drupal\toolshed\Strategy\StrategyFactoryInterface;

/**
 * The strategy manager for report renderers.
 */
class ReportRenderManager extends ReportRenderManagerBase {

  /**
   * Creates a new instance of the ReportSummaryManager strategy manager.
   *
   * @param \Drupal\Core\Config\ConfigFactoryInterface $configFactory
   *   The configuration factory manager service.
   * @param \Drupal\Core\Extension\ModuleHandlerInterface $moduleHandler
   *   The module handler.
   * @param \Drupal\Core\Cache\CacheBackendInterface $cacheBackend
   *   The discovery cache backend to store discovery items.
   * @param \Drupal\toolshed\Strategy\StrategyFactoryInterface $factory
   *   The strategy factory interface.
   */
  public function __construct(
    ConfigFactoryInterface $configFactory,
    ModuleHandlerInterface $moduleHandler,
    CacheBackendInterface $cacheBackend,
    StrategyFactoryInterface $factory,
  ) {
    parent::__construct(
      [
        'name' => 'report_station.report',
        'attribute' => ReportRenderer::class,
      ],
      $moduleHandler,
      $cacheBackend,
      ['report_station_render'],
      $factory
    );

    $this->strategyInterface = ReportRenderInterface::class;
    $config = $configFactory->get('report_station.settings');
    $this->renderMap = array_filter($config->get('renderers') ?? [
      'php' => 'php',
      'drupal' => 'drupal',
      'composer' => 'composer',
    ]);
  }

}
