<?php

namespace Drupal\report_station\Strategy;

use Drupal\toolshed\Strategy\StrategyManagerInterface;

/**
 * Interface for the render strategies for building report beacon displays.
 */
interface ReportRenderManagerInterface extends StrategyManagerInterface {

  /**
   * Builds render arrays for report data provided.
   *
   * @param array $data
   *   The report data to render.
   *
   * @return array
   *   Renderable array result expected from the rendering type.
   */
  public function render(array $data): array;

  /**
   * Get the configured renderer to use for the requested beacon type.
   *
   * @param string $beaconType
   *   The server beacon plugin ID to get current render strategy for.
   *
   * @return \Drupal\report_station\Strategy\ReportRenderInterface|null
   *   A loaded render strategy to use for the requested server beacon type.
   */
  #[\ReturnTypeWillChange]
  public function getRenderer(string $beaconType): ?ReportRenderInterface;

  /**
   * Get a list of available render options for a server beacon plugin.
   *
   * @param string|null $beaconType
   *   The server beacon plugin ID to fetch render options for. To get all
   *   all available options for all beacon plugins, use "NULL".
   *
   * @return array<string,\Stringable|string|array<\Stringable|string>>
   *   A list of compatible render strategy options. Strategy ID is the array
   *   key and a display label is the array value. If no $beaconType provided
   *   then a list of all available renderers will be returned by type.
   */
  public function getRenderOptions(?string $beaconType = NULL): array;

}
