<?php

namespace Drupal\report_station\Strategy\ReportStation\Report;

use Drupal\Component\Render\FormattableMarkup;
use Drupal\Core\StringTranslation\StringTranslationTrait;
use Drupal\Core\StringTranslation\TranslatableMarkup;
use Drupal\report_station\Attribute\ReportRenderer;
use Drupal\report_station\Strategy\ReportRenderInterface;
use Drupal\toolshed\Strategy\StrategyBase;

/**
 * Renders Drupal server beacon report data into a nice display.
 */
#[ReportRenderer(
  id: 'drupal',
  label: new TranslatableMarkup('Drupal renderer'),
  beacon_types: [
    'drupal',
  ])
]
class DrupalRender extends StrategyBase implements ReportRenderInterface {

  use StringTranslationTrait;

  /**
   * {@inheritdoc}
   */
  public function __invoke(string $beaconType, array $data): array {
    $build = [
      '#theme_wrappers' => ['report_station_section'],
      '#beacon_type' => $beaconType,
      '#title' => $this->t('Drupal info'),

      'drupal' => [
        '#type' => 'html_tag',
        '#tag' => 'h3',
        '#value' => $this->t('Core: @version', [
          '@version' => $data['drupal'],
        ]),
      ],
    ];

    if (!empty($data['db'])) {
      $build['database'] = [
        '#type' => 'html_tag',
        '#tag' => 'h3',
        '#value' => new FormattableMarkup('@driver: @version', [
          '@driver' => $data['db']['driver'],
          '@version' => $data['db']['version'] ?? $this->t('unknown'),
        ]),
      ];
    }

    if (!empty($data['contrib'])) {
      $rows = [];
      foreach ($data['contrib'] as $extension => [
        'name' => $name,
        'type' => $type,
        'version' => $version,
        'latest' => $latest,
        'insecure' => $insecure,
      ]) {
        $rows[$extension] = [
          'class' => $insecure ? ['report-item--warning'] : [],
          'data' => [
            'name' => [
              'data' => ['#plain_text' => $name],
              'class' => ['extension__name'],
            ],
            'type' => [
              'data' => ['#plain_text' => $type],
              'class' => ['extension__type', RESPONSIVE_PRIORITY_LOW],
            ],
            'version' => [
              'data' => ['#plain_text' => $version],
              'class' => ['extension__version'],
            ],
            'latest' => [
              'data' => ['#plain_text' => $latest],
              'class' => ['extension__recommend-version'],
            ],
          ],
        ];
      }

      $build['contrib'] = [
        '#type' => 'table',
        '#attributes' => ['class' => ['responsive-enabled']],
        '#header' => [
          'name' => $this->t('Extension'),
          'type' => [
            'data' => $this->t('Type'),
            'class' => [RESPONSIVE_PRIORITY_LOW],
          ],
          'version' => $this->t('Installed'),
          'latest' => $this->t('Recommended'),
        ],
        '#rows' => $rows,
      ];
    }
    elseif (!empty($data['_msg']['contrib'])) {
      $build['contrib']['msg'] = [
        '#theme_wrappers' => ['report_station_status_message'],
        '#title' => $this->t('Drupal core & contrib'),
        '#status_type' => 'warning',

        'content' => [
          '#plain_text' => $data['_msg']['contrib'],
        ],
      ];
    }

    return $build;
  }

}
