<?php

namespace Drupal\report_station\Strategy\ReportStation\Report;

use Drupal\Component\Render\FormattableMarkup;
use Drupal\Core\StringTranslation\StringTranslationTrait;
use Drupal\Core\StringTranslation\TranslatableMarkup;
use Drupal\report_station\Attribute\ReportRenderer;
use Drupal\report_station\Strategy\ReportRenderInterface;
use Drupal\toolshed\Strategy\StrategyBase;

/**
 * Renders PHP server beacon report data into a nice display.
 */
#[ReportRenderer(
  id: 'php',
  label: new TranslatableMarkup('PHP renderer'),
  beacon_types: [
    'php',
  ])
]
class PhpRender extends StrategyBase implements ReportRenderInterface {

  use StringTranslationTrait;

  /**
   * {@inheritdoc}
   */
  public function __invoke(string $beaconType, array $data): array {
    $build = [
      '#theme_wrappers' => ['report_station_section'],
      '#beacon_type' => $beaconType,
      '#title' => $this->t('PHP & System info'),
    ];

    if (isset($data['extensions']['php'])) {
      $build['php'] = [
        '#type' => 'html_tag',
        '#tag' => 'h3',
        '#value' => $this->t('PHP version: @version', [
          '@version' => $data['extensions']['php'],
        ]),
      ];
    }

    $osValue = $data['os']['PRETTY_NAME'] ?? $data['os']['ID'] ?? NULL;
    if ($osValue) {
      $build['os'] = [
        '#type' => 'html_tag',
        '#tag' => 'h3',
        '#value' => $this->t('OS: @os_info', [
          '@os_info' => $osValue,
        ]),
      ];
    }

    if (!empty($data['webserver'])) {
      $build['webserver'] = [
        '#type' => 'html_tag',
        '#tag' => 'h3',
        '#value' => $this->t('Webserver: @server_info (@build)', [
          '@server_info' => $data['webserver']['type'] ?? '',
          '@build' => $data['webserver']['build'] ?? '',
        ]),
      ];
    }

    // Display PHP versions depending on single or multiple extensions.
    if (count($data['extensions']) > 1) {
      $items = [];
      foreach ($data['extensions'] as $extName => $version) {
        $items[$extName] = new FormattableMarkup('@extension (%version)', [
          '@extension' => $extName,
          '%version' => $version,
        ]);
      }

      $build['php_extensions'] = [
        '#theme' => 'item_list',
        '#title' => $this->t('PHP Extensions'),
        '#items' => $items,
        '#weight' => 99,
      ];
    }

    return $build;
  }

}
