<?php

namespace Drupal\report_station\Strategy\ReportStation\Summarizer;

use Drupal\Component\Render\FormattableMarkup;
use Drupal\Core\StringTranslation\StringTranslationTrait;
use Drupal\Core\StringTranslation\TranslatableMarkup;
use Drupal\report_station\Attribute\ReportRenderer;
use Drupal\report_station\Strategy\ReportRenderInterface;
use Drupal\toolshed\Strategy\StrategyBase;

/**
 * Renders beacon report summaries for data from the Composer beacon type.
 */
#[ReportRenderer(
  id: 'composer',
  label: new TranslatableMarkup('Composer summary'),
  beacon_types: ['composer'],
)]
class ComposerSummarizer extends StrategyBase implements ReportRenderInterface {

  use StringTranslationTrait;

  /**
   * Get the primary Composer audit type values.
   *
   * @return array<string,\Stringable|string>
   *   The array key as the audit type, and the label as the array value.
   */
  public function getAuditTypes(): array {
    return [
      'advisories' => $this->t('Advisories'),
      'abandoned' => $this->t('Abandoned'),
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function __invoke(string $beaconType, array $data): array {
    $status = [];
    $params = [];
    foreach ($this->getAuditTypes() as $type => $label) {
      if (isset($data[$type])) {
        $status[] = "@{$type}_label: %{$type}";
        $params["@{$type}_label"] = $label;
        $params["%{$type}"] = count($data[$type]);
        $warn = TRUE;
      }
    }

    if (isset($data['outdated'])) {
      $status[] = '@outdated_label: %outdated';
      $params['@outdated_label'] = $this->t('outdated');
      $params['%outdated'] = count($data['outdated']['packages']);
    }

    return [
      [
        'value' => new FormattableMarkup(implode(', ', $status), $params),
        'warn' => !empty($warn),
      ],
    ];
  }

}
