<?php

namespace Drupal\report_station\Strategy\ReportStation\Summarizer;

use Drupal\Core\StringTranslation\StringTranslationTrait;
use Drupal\Core\StringTranslation\TranslatableMarkup;
use Drupal\report_station\Attribute\ReportRenderer;
use Drupal\report_station\Strategy\ReportRenderInterface;
use Drupal\toolshed\Strategy\StrategyBase;

/**
 * Renders beacon report summaries for data from the Drupal beacon plugin.
 */
#[ReportRenderer(
  id: 'drupal',
  label: new TranslatableMarkup('Drupal summary'),
  beacon_types: ['drupal'],
)]
class DrupalSummarizer extends StrategyBase implements ReportRenderInterface {

  use StringTranslationTrait;

  /**
   * {@inheritdoc}
   */
  public function __invoke(string $beaconType, array $data): array {
    $summary = [];
    $params = [
      '@version' => $data['drupal'],
    ];

    if (isset($data['contrib'])) {
      $params['@count'] = count($data['contrib']);

      foreach ($data['contrib'] as $info) {
        if (!empty($info['insecure'])) {
          $params['%security'] = $this->t('has security');
          $summary['drupal']['value'] = $this->t('Core: @version (@count updates - %security)', $params);
          $summary['drupal']['warn'] = TRUE;
          return $summary;
        }
      }
      $summary['drupal']['value'] = $this->t('Core: @version (@count updates)', $params);
    }
    else {
      $summary['drupal']['value'] = $this->t('Core: @version', $params);
    }

    return $summary;
  }

}
