<?php

namespace Drupal\report_station\Strategy\ReportStation\Summarizer;

use Drupal\Core\StringTranslation\StringTranslationTrait;
use Drupal\Core\StringTranslation\TranslatableMarkup;
use Drupal\report_station\Attribute\ReportRenderer;
use Drupal\report_station\Strategy\ReportRenderInterface;
use Drupal\toolshed\Strategy\StrategyBase;

/**
 * Renders beacon report summaries for data from the PHP beacon type.
 */
#[ReportRenderer(
  id: 'php',
  label: new TranslatableMarkup('PHP summary'),
  beacon_types: ['php'],
)]
class PhpSummarizer extends StrategyBase implements ReportRenderInterface {

  use StringTranslationTrait;

  /**
   * {@inheritdoc}
   */
  public function __invoke(string $beaconType, array $data): array {
    $params = [
      '@php_version' => $data['extensions']['php'] ?? new TranslatableMarkup('unknown'),
    ];

    if (!empty($data['webserver']['type'])) {
      $params['@webserver'] = $data['webserver']['type'];
      $content = $this->t('Version: @php_version on @webserver', $params);
    }
    else {
      $content = $this->t('Version: @php_version', $params);
    }

    $summary[] = ['value' => $content];
    return $summary;
  }

}
