<?php

namespace Drupal\report_station\Strategy;

use Drupal\Core\Cache\CacheBackendInterface;
use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Extension\ModuleHandlerInterface;
use Drupal\report_station\Attribute\ReportRenderer;

/**
 * The strategy manager for report summary renderers.
 */
class ReportSummaryManager extends ReportRenderManagerBase {

  /**
   * Creates a new instance of the ReportSummaryManager strategy manager.
   *
   * @param \Drupal\Core\Config\ConfigFactoryInterface $configFactory
   *   The configuration factory manager service.
   * @param \Drupal\Core\Extension\ModuleHandlerInterface $moduleHandler
   *   The module handler.
   * @param \Drupal\Core\Cache\CacheBackendInterface $cacheBackend
   *   The discovery cache backend to store discovery items.
   */
  public function __construct(ConfigFactoryInterface $configFactory, ModuleHandlerInterface $moduleHandler, CacheBackendInterface $cacheBackend) {
    parent::__construct(
      [
        'name' => 'report_station.summarizer',
        'attribute' => ReportRenderer::class,
      ],
      $moduleHandler,
      $cacheBackend,
      ['report_station_summary'],
    );

    $config = $configFactory->get('report_station.settings');
    $this->renderMap = array_filter($config->get('summarizers') ?? [
      'php' => 'php',
      'drupal' => 'drupal',
      'composer' => 'composer',
    ]);

    $this->strategyInterface = ReportRenderInterface::class;
  }

}
